@@ -1,10 +1,10 @@
 """Batch sync files."""
 
 from logging import basicConfig
-from multiprocessing import Pool
 
 from homeinfotools.functions import get_log_level, handle_keyboard_interrupt
 from homeinfotools.logging import LOG_FORMAT
+from homeinfotools.multiprocessing import multiprocess
 from homeinfotools.filetransfer.argparse import get_args
 from homeinfotools.filetransfer.worker import Worker
 
@@ -18,6 +18,4 @@ def main() -> None:
 
     args = get_args()
     basicConfig(format=LOG_FORMAT, level=get_log_level(args))
-
-    with Pool(processes=args.processes) as pool:
-        pool.map(Worker(args), args.system)
+    multiprocess(Worker, args)
