@@ -1,15 +1,15 @@
 """Processing of systems."""
 
 from homeinfotools.filetransfer.filetransfer import filetransfer
-from homeinfotools.worker import BaseWorker
+from homeinfotools.multiprocessing import BaseWorker
 
 
 __all__ = ['Worker']
 
 
-class Worker(BaseWorker):   # pylint: disable=R0903
+class Worker(BaseWorker):
     """Stored args and manager to process systems."""
 
-    def run(self, system: int, result: dict) -> None:
+    def run(self, system: int) -> dict:
         """Runs the worker."""
-        result['sysupgrade'] = filetransfer(system, self.args)
+        return {'rsync': filetransfer(system, self.args)}
