@@ -1,6 +1,6 @@
 """Processing of systems."""
 
-from homeinfotools.worker import BaseWorker
+from homeinfotools.multiprocessing import BaseWorker
 from homeinfotools.rpc.reboot import reboot
 from homeinfotools.rpc.runcmd import runcmd
 from homeinfotools.rpc.sysupgrade import sysupgrade
@@ -9,11 +9,13 @@ from homeinfotools.rpc.sysupgrade import sysupgrade
 __all__ = ['Worker']
 
 
-class Worker(BaseWorker):   # pylint: disable=R0903
+class Worker(BaseWorker):
     """Stored args and manager to process systems."""
 
-    def run(self, system: int, result: dict) -> None:
+    def run(self, system: int) -> dict:
         """Runs the worker."""
+        result = {}
+
         if self.args.sysupgrade:
             result['sysupgrade'] = sysupgrade(system, self.args)
 
@@ -22,3 +24,5 @@ class Worker(BaseWorker):   # pylint: disable=R0903
 
         if self.args.reboot:
             result['reboot'] = reboot(system, self.args)
+
+        return result
